# Package Overview
<p align="justify">
<i>Wordhoard</i> is an application that can be used to build comprehensive antonyms, synonyms, hypernyms, hyponyms and homophones lists for words.  It can also be used to obtain 
definitions for words.  

More details documentation and usage examples are located at the following <a href="https://github.com/johnbumgarner/wordhoard/blob/master/README.md">link</a> on GitHub.
<p>

# Current Version
<p align="justify">

   - Version 1.4
   - Release type: enhancement
   - Release date: 06-12-2021
<p>

# Installation Details

## Install via pip3

```python
pip3 install wordhoard
```

## Dependencies
1. BeautifulSoup (bs4)
2. lxml
3. requests
4. urllib3

# Licence 
<p align="justify">
Distributed under the <a href="https://github.com/johnbumgarner/wordhoard/blob/master/LICENSE">MIT Licence</a>
<p>

# Developed by:
<p align="justify">
Copyright (C) 2020 John Bumgarner
<p>
